# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/tick_analytics/v1/tick_spread.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import side_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_side__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>systemathics/apis/services/tick_analytics/v1/tick_spread.proto\x12,systemathics.apis.services.tick_analytics.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a+systemathics/apis/type/shared/v1/side.proto\"\xa1\x02\n\x11TickSpreadRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x42\n\x0b\x63onstraints\x18\x02 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\x12\x32\n\x0cmin_accepted\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x32\n\x0cmax_accepted\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x0e\n\x06\x61\x63\x63\x65pt\x18\x05 \x03(\t\x12\x0e\n\x06reject\x18\x06 \x03(\t\"\xf7\x01\n\x12TickSpreadResponse\x12\x43\n\x03\x62id\x18\x01 \x01(\x0b\x32\x36.systemathics.apis.services.tick_analytics.v1.SideData\x12\x43\n\x03\x61sk\x18\x02 \x01(\x0b\x32\x36.systemathics.apis.services.tick_analytics.v1.SideData\x12\x0c\n\x04last\x18\x03 \x01(\x01\x12\x0f\n\x07\x61verage\x18\x04 \x01(\x01\x12\x0b\n\x03min\x18\x05 \x01(\x01\x12\x0b\n\x03max\x18\x06 \x01(\x01\x12\r\n\x05\x63ount\x18\x07 \x01(\x03\x12\x0f\n\x07skipped\x18\x08 \x01(\x03\"p\n\x08SideData\x12\x0c\n\x04last\x18\x01 \x01(\x01\x12\x0f\n\x07\x61verage\x18\x02 \x01(\x01\x12\x0c\n\x04vwap\x18\x03 \x01(\x01\x12\x0b\n\x03min\x18\x04 \x01(\x01\x12\x0b\n\x03max\x18\x05 \x01(\x01\x12\x0e\n\x06volume\x18\x06 \x01(\x03\x12\r\n\x05\x63ount\x18\x07 \x01(\x03\x32\xa7\x01\n\x11TickSpreadService\x12\x91\x01\n\nTickSpread\x12?.systemathics.apis.services.tick_analytics.v1.TickSpreadRequest\x1a@.systemathics.apis.services.tick_analytics.v1.TickSpreadResponse0\x01\x62\x06proto3')



_TICKSPREADREQUEST = DESCRIPTOR.message_types_by_name['TickSpreadRequest']
_TICKSPREADRESPONSE = DESCRIPTOR.message_types_by_name['TickSpreadResponse']
_SIDEDATA = DESCRIPTOR.message_types_by_name['SideData']
TickSpreadRequest = _reflection.GeneratedProtocolMessageType('TickSpreadRequest', (_message.Message,), {
  'DESCRIPTOR' : _TICKSPREADREQUEST,
  '__module__' : 'systemathics.apis.services.tick_analytics.v1.tick_spread_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick_analytics.v1.TickSpreadRequest)
  })
_sym_db.RegisterMessage(TickSpreadRequest)

TickSpreadResponse = _reflection.GeneratedProtocolMessageType('TickSpreadResponse', (_message.Message,), {
  'DESCRIPTOR' : _TICKSPREADRESPONSE,
  '__module__' : 'systemathics.apis.services.tick_analytics.v1.tick_spread_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick_analytics.v1.TickSpreadResponse)
  })
_sym_db.RegisterMessage(TickSpreadResponse)

SideData = _reflection.GeneratedProtocolMessageType('SideData', (_message.Message,), {
  'DESCRIPTOR' : _SIDEDATA,
  '__module__' : 'systemathics.apis.services.tick_analytics.v1.tick_spread_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick_analytics.v1.SideData)
  })
_sym_db.RegisterMessage(SideData)

_TICKSPREADSERVICE = DESCRIPTOR.services_by_name['TickSpreadService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TICKSPREADREQUEST._serialized_start=358
  _TICKSPREADREQUEST._serialized_end=647
  _TICKSPREADRESPONSE._serialized_start=650
  _TICKSPREADRESPONSE._serialized_end=897
  _SIDEDATA._serialized_start=899
  _SIDEDATA._serialized_end=1011
  _TICKSPREADSERVICE._serialized_start=1014
  _TICKSPREADSERVICE._serialized_end=1181
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/type/shared/v1/condition.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0systemathics/apis/type/shared/v1/condition.proto\x12 systemathics.apis.type.shared.v1\"b\n\tCondition\x12\r\n\x05value\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0f\n\x07\x63omment\x18\x03 \x01(\t\x12\x0f\n\x07regular\x18\x04 \x01(\x08\x12\x0f\n\x07\x61uction\x18\x05 \x01(\x08\x62\x06proto3')



_CONDITION = DESCRIPTOR.message_types_by_name['Condition']
Condition = _reflection.GeneratedProtocolMessageType('Condition', (_message.Message,), {
  'DESCRIPTOR' : _CONDITION,
  '__module__' : 'systemathics.apis.type.shared.v1.condition_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.type.shared.v1.Condition)
  })
_sym_db.RegisterMessage(Condition)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CONDITION._serialized_start=86
  _CONDITION._serialized_end=184
# @@protoc_insertion_point(module_scope)
